@@ -8,10 +8,10 @@ System System1984 = {
   .BRACKETS = { 0, 4595, 19500, 35788, INT_MAX, INT_MAX, INT_MAX, INT_MAX },
   .RATES = { 0, 0.3, 0.46, 0.6, 0.6, 0.6, 0.6, 0.6 },
   .M = {
-    .lwr_single = 6699,
-    .upr_single = 7882,
-    .lwr_family = 11141,
-    .upr_family = 13108,
+    .lwr_single = 7111, // 6699,
+    .upr_single = 7485, // 7882, not sure where this came from
+    .lwr_family = 11804, //11141,
+    .upr_family = 12426, // 13108,
     .has_sapto_thr = true,
     .sapto_age = 65,
     .lwr_single_sapto = 1984,
@@ -20,7 +20,7 @@ System System1984 = {
     .upr_family_sapto = 19815304,
     .lwr_thr_up_per_child = 1100,
     .taper = 0.25,
-    .rate = 0.0125
+    .rate = 0.01
   },
   .has_sapto = false,
   .S = {
