@@ -1,11 +1,11 @@
 context("model_income_tax")
 
 test_that("Error handling", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
-  skip_on_circleci(2)
-  library(taxstats)
+  skip_on_cran()
+  skip_without_sample_files()
   library(hutils)
-  sample_file_1314_copy <- copy(sample_file_1314)
+  sample_file_1314 <- .sample_file_1314()
+  sample_file_1314_copy <- copy(.sample_file_1314())
   s_no_ti <- 
     sample_file_1314_copy %>%
     copy %>%
@@ -22,7 +22,7 @@ test_that("Error handling", {
   
   
 
-  original <- income_tax(sample_file_1314$Taxable_Income, "2013-14", .dots.ATO = copy(sample_file_1314))
+  original <- income_tax(sample_file_1314$Taxable_Income, "2013-14", .dots.ATO = copy(.sample_file_1314()))
   
   new_tax <- model_income_tax(sample_file_1314_copy,
                               baseline_fy = "2013-14",
@@ -34,9 +34,10 @@ test_that("Error handling", {
 })
 
 test_that("La plus ca meme la plus ca meme: la deluge", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
+
+  sample_file_1112 <- .sample_file_("1112")
   sample_file_1112_copy <- copy(sample_file_1112)
   original <-
     income_tax(sample_file_1112_copy$Taxable_Income,
@@ -54,10 +55,10 @@ test_that("La plus ca meme la plus ca meme: la deluge", {
 })
 
 test_that("La plus ca meme la plus ca meme: medicare levy", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1314_copy <- copy(sample_file_1314)
+
+  sample_file_1314_copy <- copy(.sample_file_1314())
   
   original <- 
     income_tax(sample_file_1314_copy$Taxable_Income,
@@ -74,10 +75,10 @@ test_that("La plus ca meme la plus ca meme: medicare levy", {
 })
 
 test_that("La plus ca meme la plus ca meme: LITO", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1314_copy <- copy(sample_file_1314)
+  
+  sample_file_1314_copy <- copy(.sample_file_1314())
   
   original <- 
     income_tax(sample_file_1314_copy$Taxable_Income,
@@ -94,12 +95,11 @@ test_that("La plus ca meme la plus ca meme: LITO", {
 })
 
 test_that("La plus ca meme la plus ca meme: SBTO doesn't interfere with SBTO", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
   library(magrittr)
   library(data.table)
-  sample_file_1314_copy <- copy(sample_file_1314)
+  sample_file_1314_copy <- copy(.sample_file_1314())
   sample_file_81913 <- 
     sample_file_1314_copy %>%
     .[Ind == 81913] %T>%
@@ -112,11 +112,11 @@ test_that("La plus ca meme la plus ca meme: SBTO doesn't interfere with SBTO", {
 })
 
 test_that("Increase in a rate results in more tax", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1314_copy <- copy(sample_file_1314)
-  original <- income_tax(sample_file_1314$Taxable_Income, "2013-14", .dots.ATO = copy(sample_file_1314))
+  
+  sample_file_1314_copy <- copy(.sample_file_1314())
+  original <- income_tax(.sample_file_1314()$Taxable_Income, "2013-14", .dots.ATO = copy(.sample_file_1314()))
   original <- round(original)
   
   new_tax <-
@@ -135,10 +135,9 @@ test_that("Increase in a rate results in more tax", {
 })
 
 test_that("Medicare warnings", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1314_copy <- copy(sample_file_1314)
+  sample_file_1314_copy <- copy(.sample_file_1314())
   expect_warning(model_income_tax(sample_file_1314_copy,
                                   baseline_fy = "2013-14",
                                   
@@ -243,13 +242,13 @@ test_that("Medicare warnings", {
 })
 
 test_that("Medicare options", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1314_copy <- copy(sample_file_1314)
-  original <- income_tax(sample_file_1314$Taxable_Income,
+  
+  sample_file_1314_copy <- copy(.sample_file_1314())
+  original <- income_tax(sample_file_1314_copy$Taxable_Income,
                          fy.year = "2013-14",
-                         .dots.ATO = copy(sample_file_1314))
+                         .dots.ATO = copy(sample_file_1314_copy))
   
   expect_warning(model_income_tax(sample_file_1314_copy,
                                   baseline_fy = "2013-14",
@@ -259,7 +258,7 @@ test_that("Medicare options", {
                  regexp = "medicare_levy_upper_threshold = 25677")
   
   sample_file_1314_if_2pc_ML <-
-    sample_file_1314 %>%
+    sample_file_1314_copy %>%
     copy %>%
     .[, old_tax := income_tax(Taxable_Income, "2013-14", .dots.ATO = .)] %>%
     .[, new_tax := model_income_tax(sample_file_1314_copy,
@@ -323,9 +322,8 @@ test_that("Medicare options", {
 
 test_that("Medicare families", {
   skip_on_cran()
-  skip_if_not_installed("taxstats"); skip_on_cran()
   skip_on_circleci(2)
-  s1617 <- project(sample_file_1314, h = 3L)
+  s1617 <- project(.sample_file_1314(), h = 3L)
   
   for (j in seq_along(s1617)) {
     if (is.double(s1617[[j]])) {
@@ -360,10 +358,8 @@ test_that("Medicare families", {
 
 test_that("SAPTO modelled", {
   skip_on_cran()
-  skip_if_not_installed("taxstats", minimum_version = "0.0.5")
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1415_copy <- copy(sample_file_1415_synth)
+  sample_file_1415_copy <- copy(.sample_file_1415())
   
   expect_warning({
     model_income_tax(sample_file_1415_copy,
@@ -418,7 +414,7 @@ test_that("SAPTO modelled", {
   
   
   sapto_only_psnn <-
-    copy(sample_file_1415_synth) %>%
+    copy(.sample_file_1415()) %>%
     project_to(to_fy = "2016-17") %>%
     .[, saptoEligible := and(age_range <= 1L, Aust_govt_pnsn_allw_amt > 1)] %>%
     # The partner contribution makes the extra revenue much higher
@@ -437,10 +433,9 @@ test_that("SAPTO modelled", {
 })
 
 test_that("LITO", {
-  skip_if_not_installed("taxstats"); skip_on_cran()
+  skip_on_cran()
   skip_on_circleci(2)
-  library(taxstats)
-  sample_file_1213_copy <- copy(sample_file_1213)
+  sample_file_1213_copy <- copy(.sample_file_("1213"))
   
   old_taxes <-
     copy(sample_file_1213_copy) %>%
@@ -461,11 +456,10 @@ test_that("LITO", {
 
 test_that("Elasticity of taxable income", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
+  
   s12131314 <- 
-    copy(sample_file_1213) %>%
+    copy(.sample_file_("1213")) %>%
     .[Ind %% 3 == 0] %>%
     setkey(Ind)
   
@@ -544,11 +538,9 @@ test_that("Elasticity of taxable income", {
 
 
 test_that("Elasticity 0 vs 1", {
-  skip_if_not_installed("taxstats", minimum_version = "0.0.5")
   skip_on_circleci(2)
-  library(taxstats)
   s1415 <- 
-    copy(sample_file_1415_synth) %>%
+    copy(.sample_file_("1415_synth")) %>%
     .[, old_tax := income_tax(Taxable_Income, "2014-15", .dots.ATO = .)] %>%
     unique(by = "Ind")
   
@@ -587,7 +579,6 @@ test_that("Elasticity 0 vs 1", {
 
 test_that("Lamington", {
   skip_on_cran()
-  skip_if_not_installed("taxstats", minimum_version = "0.0.5")
   skip_if_not_installed("fst", minimum_version = "0.8.4")
   skip_on_circleci(2)
   temp.fst <- "~/SampleFile1819/sample_file_1819.fst"
@@ -630,10 +621,8 @@ test_that("Lamington", {
 
 test_that("Clear columns", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
-  s1314 <- as.data.table(sample_file_1314)
+  s1314 <- as.data.table(.sample_file_1314())
   s1314[, new_tax := 1][, baseline_tax := 2]
   res <- model_income_tax(s1314, "2013-14", clear_tax_cols = TRUE)
   expect_true(res[, max(new_tax)] > 1)
@@ -641,10 +630,8 @@ test_that("Clear columns", {
 
 test_that("sample_file.int", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
-  s1314 <- as.data.table(sample_file_1314)
+  s1314 <- as.data.table(.sample_file_1314())
   res <- model_income_tax(s1314, "2013-14", return. = "sample_file.int")
   expect_identical(res[["new_tax"]], res[["baseline_tax"]])
 })
@@ -654,10 +641,8 @@ test_that("sample_file.int", {
 
 test_that("Keyed data.table", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
-  s1314 <- as.data.table(sample_file_1314)
+  s1314 <- as.data.table(.sample_file_1314())
   base <- model_income_tax(s1314, "2013-14", sbto_discount = 0.1)
   setkey(s1314, Taxable_Income)
   new <- model_income_tax(s1314, "2013-14", sbto_discount = 0.1)
@@ -667,11 +652,11 @@ test_that("Keyed data.table", {
 
 test_that("Budget2018", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
+  
   skip_on_circleci(2)
-  library(taxstats)
+  
   library(hutilscpp)
-  s1314 <- as.data.table(sample_file_1314)
+  s1314 <- as.data.table(.sample_file_1314())
   sWatr <- model_income_tax(s1314,
                             baseline_fy =  "2013-14",
                             Budget2018_watr = TRUE,
@@ -701,13 +686,11 @@ test_that("Budget2018", {
 
 test_that("CGT discount", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
-  skip_if_not_installed("taxstats1516")
+  
+  
   skip_on_circleci(2)
-  library(taxstats)
-  library(taxstats1516)
   library(data.table)
-  s12131314 <- copy(sample_file_1213)
+  s12131314 <- copy(.sample_file_("1213"))
   baseline <- model_income_tax(s12131314,
                                "2013-14",
                                ordinary_tax_thresholds = c(0, 20e3, 37e3, 80e3, 180e3))
@@ -735,8 +718,8 @@ test_that("CGT discount", {
                                 cgt_discount_rate = 0.5,
                                 return. = "tax"))
   # TES 2015-16: 5160 for full discount
-  s1516_orig <- copy(taxstats1516::sample_file_1516_synth)
-  s1516 <- model_income_tax(s1516_orig, 
+  s1516_orig <- copy(.sample_file_1516())
+  s1516 <- model_income_tax(copy(s1516_orig)[, Partner_status := 0L], 
                             baseline_fy = "2015-16",
                             cgt_discount_rate = 0.0)
   s1516[, WEIGHT := 50L]
@@ -776,14 +759,12 @@ test_that("CGT discount", {
 
 test_that("CGT (errors)", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
-  expect_error(model_income_tax(sample_file_1213, "2013-14", 
+  expect_error(model_income_tax(.sample_file_("1213"), "2013-14", 
                                 cgt_discount_rate = rep(0, 5)),
                regexp = "length(cgt_discount_rate) = 5",
                fixed = TRUE)
-  expect_error(model_income_tax(sample_file_1213, "2013-14", 
+  expect_error(model_income_tax(.sample_file_("1213"), "2013-14", 
                                 cgt_discount_rate = "x"),
                regexp = "`cgt_discount_rate` was type character",
                fixed = TRUE)
@@ -791,22 +772,18 @@ test_that("CGT (errors)", {
 
 test_that("SAPTO parameters should not go out of range (causing NAs)", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
   library(data.table)
   library(hutils)
-  s1314 <- as.data.table(sample_file_1314)
+  s1314 <- as.data.table(.sample_file_1314())
   m1314_27000 <- model_income_tax(s1314, "2016-17", sapto_lower_threshold = 27000)
   expect_false(anyNA(m1314_27000[["new_tax"]]))
 })
 
 test_that("Issue #176", {
-  skip_if_not_installed("taxstats")
   skip_on_circleci(3)
-  library(taxstats)
   # Just no error
-  expect_silent(model_income_tax(copy(sample_file_1314), 
+  expect_silent(model_income_tax(copy(.sample_file_1314()), 
                                  "2016-17", 
                                  medicare_levy_lower_family_sapto_threshold = 42000,
                                  medicare_levy_upper_family_sapto_threshold = 52500))
@@ -815,14 +792,12 @@ test_that("Issue #176", {
 
 test_that("SAPTO modelling done for Age of entitlement report", {
   skip_on_cran()
-  skip_if_not_installed("taxstats")
   skip_on_circleci(2)
-  library(taxstats)
   library(data.table)
   library(hutils)
   library(hutilscpp)
   s1718_AgeOfEntitlement <-
-    project(sample_file_1314, 
+    project(.sample_file_1314(), 
             h = 4L) %>%
     model_income_tax("2017-18", 
                      sapto_lower_threshold = 27e3,
